@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 from analysis.shared.util.string_builder import StringBuilder
 from .annotateapp_builder import AnnotateAppBuilder
 
@@ -18,6 +16,7 @@ class AnnotateLauncher(object):
         ab.set_tsv_file(args.tsv)
         ab.set_seed(args.seed)
         ab.set_mds(args.mds)
+        ab.set_umap(args.umap)
         ab.set_linkage_method(args.linkage)
         ab.set_rescale(args.rescale)
         ab.set_md5sum(args.md5sum)
