@@ -1,16 +1,17 @@
 from analysis.ari.ariapp import AriApp
 
+
 class AriAppBuilder:
     def __init__(self):
         self.params = {
-            'matrix_filename':None,
-            'metadata_filename':None,
-            'linkage_method':None,
-            'breakdown_categories':None,
-            'restriction_categories':None,
-            'title':None,
-            'ignore_user':None,
-            'md5sum':False
+            'matrix_filename': None,
+            'metadata_filename': None,
+            'linkage_method': None,
+            'breakdown_categories': None,
+            'restriction_categories': None,
+            'title': None,
+            'ignore_user': None,
+            'md5sum': False
         }
 
     def set_matrix_filename(self, matrix_filename):
@@ -40,6 +41,7 @@ class AriAppBuilder:
     def build(self):
         for k, p in self.params.items():
             if p is None:
-                raise Exception('The parameter:\'' + k + '\' is not specified.')
+                raise Exception('The parameter:\'' + k +
+                                '\' is not specified.')
 
         return AriApp(self.params)
