@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 import argparse
 
 from .config import VERSION, NAME, DESCRIPTION
@@ -8,12 +6,14 @@ from .ari.parser import EvaluateParser
 from .slice.parser import SliceFilenameParser, SliceClusterParser
 from .util.parser import CatParser, GrepParser
 
+
 class InputParser(object):
     @staticmethod
     def parse_args(args):
-        parser = argparse.ArgumentParser(prog=NAME, description = DESCRIPTION)
-        parser.add_argument('-v', '--version', action='version', version='%(prog)s {0}'.format(VERSION))
-        subparsers = parser.add_subparsers(help = "Sub-command help.")
+        parser = argparse.ArgumentParser(prog=NAME, description=DESCRIPTION)
+        parser.add_argument('-v', '--version', action='version',
+                            version='%(prog)s {0}'.format(VERSION))
+        subparsers = parser.add_subparsers(help="Sub-command help.")
 
         AnnotateParser.add_parser(subparsers)
         EvaluateParser.add_parser(subparsers)
@@ -21,5 +21,5 @@ class InputParser(object):
         SliceClusterParser.add_parser(subparsers)
         CatParser.add_parser(subparsers)
         GrepParser.add_parser(subparsers)
-        
+
         return parser.parse_args(args)
