@@ -1,7 +1,6 @@
-from __future__ import print_function, division, absolute_import
-
 from .launcher import SliceFilenameLauncher, SliceClusterLauncher
 
+
 class SliceFilenameParser(object):
     @staticmethod
     def add_parser(subparsers):
@@ -12,8 +11,11 @@ class SliceFilenameParser(object):
         )
         parser.set_defaults(func=SliceFilenameLauncher.run)
 
-        parser.add_argument('matrix', help='The input matrix tsv file.', type=str)
-        parser.add_argument('file_names', help='The input file_names text file.', type=str)
+        parser.add_argument(
+            'matrix', help='The input matrix tsv file.', type=str)
+        parser.add_argument(
+            'file_names', help='The input file_names text file.', type=str)
+
 
 class SliceClusterParser(object):
     @staticmethod
@@ -25,6 +27,10 @@ class SliceClusterParser(object):
         )
         parser.set_defaults(func=SliceClusterLauncher.run)
 
-        parser.add_argument('matrix', help='The input matrix tsv file.', type=str)
-        parser.add_argument('annotate_tsv', help='The input annotate tsv file.', type=str)
-        parser.add_argument('clustersnames', help='The clusters names (e.g. "A-E, H").', type=str)
+        parser.add_argument(
+            'matrix', help='The input matrix tsv file.', type=str)
+        parser.add_argument(
+            'annotate_tsv', help='The input annotate tsv file.', type=str)
+        parser.add_argument(
+            'clustersnames', help='The clusters names (e.g. "A-E, H").',
+            type=str)
